Module: Google::Cloud::CloudControlsPartner
- Defined in:
- lib/google/cloud/cloud_controls_partner.rb,
lib/google/cloud/cloud_controls_partner/version.rb
Constant Summary collapse
- VERSION =
"2.2.0"
Class Method Summary collapse
-
.cloud_controls_partner_core(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CloudControlsPartnerCore.
-
.cloud_controls_partner_core_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CloudControlsPartnerCore service is supported by the current client.
-
.cloud_controls_partner_monitoring(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CloudControlsPartnerMonitoring.
-
.cloud_controls_partner_monitoring_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CloudControlsPartnerMonitoring service is supported by the current client.
-
.configure {|::Google::Cloud.configure.cloud_controls_partner| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-cloud_controls_partner library.
Class Method Details
.cloud_controls_partner_core(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CloudControlsPartnerCore.
By default, this returns an instance of
Google::Cloud::CloudControlsPartner::V1::CloudControlsPartnerCore::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the CloudControlsPartnerCore service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the CloudControlsPartnerCore service. You can determine whether the method will succeed by calling cloud_controls_partner_core_available?.
About CloudControlsPartnerCore
Service describing handlers for resources
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/cloud/cloud_controls_partner.rb', line 75 def self.cloud_controls_partner_core version: :v1, transport: :grpc, &block require "google/cloud/cloud_controls_partner/#{version.to_s.downcase}" package_name = Google::Cloud::CloudControlsPartner .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::CloudControlsPartner.const_get(package_name).const_get(:CloudControlsPartnerCore) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.cloud_controls_partner_core_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CloudControlsPartnerCore service is supported by the current client. If true, you can retrieve a client object by calling cloud_controls_partner_core. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the CloudControlsPartnerCore service, or if the versioned client gem needs an update to support the CloudControlsPartnerCore service.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/google/cloud/cloud_controls_partner.rb', line 99 def self.cloud_controls_partner_core_available? version: :v1, transport: :grpc require "google/cloud/cloud_controls_partner/#{version.to_s.downcase}" package_name = Google::Cloud::CloudControlsPartner .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::CloudControlsPartner.const_get package_name return false unless service_module.const_defined? :CloudControlsPartnerCore service_module = service_module.const_get :CloudControlsPartnerCore if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.cloud_controls_partner_monitoring(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CloudControlsPartnerMonitoring.
By default, this returns an instance of
Google::Cloud::CloudControlsPartner::V1::CloudControlsPartnerMonitoring::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the CloudControlsPartnerMonitoring service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the CloudControlsPartnerMonitoring service. You can determine whether the method will succeed by calling cloud_controls_partner_monitoring_available?.
About CloudControlsPartnerMonitoring
Service describing handlers for resources
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/google/cloud/cloud_controls_partner.rb', line 145 def self.cloud_controls_partner_monitoring version: :v1, transport: :grpc, &block require "google/cloud/cloud_controls_partner/#{version.to_s.downcase}" package_name = Google::Cloud::CloudControlsPartner .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::CloudControlsPartner.const_get(package_name).const_get(:CloudControlsPartnerMonitoring) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.cloud_controls_partner_monitoring_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CloudControlsPartnerMonitoring service is supported by the current client. If true, you can retrieve a client object by calling cloud_controls_partner_monitoring. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the CloudControlsPartnerMonitoring service, or if the versioned client gem needs an update to support the CloudControlsPartnerMonitoring service.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/google/cloud/cloud_controls_partner.rb', line 169 def self.cloud_controls_partner_monitoring_available? version: :v1, transport: :grpc require "google/cloud/cloud_controls_partner/#{version.to_s.downcase}" package_name = Google::Cloud::CloudControlsPartner .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::CloudControlsPartner.const_get package_name return false unless service_module.const_defined? :CloudControlsPartnerMonitoring service_module = service_module.const_get :CloudControlsPartnerMonitoring if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.configure {|::Google::Cloud.configure.cloud_controls_partner| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-cloud_controls_partner library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
217 218 219 220 221 |
# File 'lib/google/cloud/cloud_controls_partner.rb', line 217 def self.configure yield ::Google::Cloud.configure.cloud_controls_partner if block_given? ::Google::Cloud.configure.cloud_controls_partner end |